pymad8 documentation
====================

pymad8 is a Python package to aid in the preparation, running and validation
of BDSIM models.

.. toctree::
   :maxdepth: 2

   licence
   authorship
   installation
   data
   plot
   convert
   simulation
   support
   moduledocs
   version_history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
